@@ -1,8 +1,7 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 from .base_visualizer_node import BaseVisualizerNode
 from .helper_nodes import MonitorNode, ObjectAssignerNode, RecorderNode
-from .model_nodes import (DetectorNode, PoseTrackerNode,
-                          TopDownPoseEstimatorNode)
+from .model_nodes import DetectorNode, TopdownPoseEstimatorNode
 from .node import Node
 from .registry import NODES
 from .visualizer_nodes import (BigeyeEffectNode, NoticeBoardNode,
@@ -10,7 +9,7 @@ from .visualizer_nodes import (BigeyeEffectNode, NoticeBoardNode,
 
 __all__ = [
     'BaseVisualizerNode', 'NODES', 'MonitorNode', 'ObjectAssignerNode',
-    'RecorderNode', 'DetectorNode', 'PoseTrackerNode',
-    'TopDownPoseEstimatorNode', 'Node', 'BigeyeEffectNode', 'NoticeBoardNode',
-    'ObjectVisualizerNode', 'ObjectAssignerNode', 'SunglassesEffectNode'
+    'RecorderNode', 'DetectorNode', 'TopdownPoseEstimatorNode', 'Node',
+    'BigeyeEffectNode', 'NoticeBoardNode', 'ObjectVisualizerNode',
+    'ObjectAssignerNode', 'SunglassesEffectNode'
 ]
