@@ -4,8 +4,9 @@ import torch.nn as nn
 import torch.nn.functional as F
 import torch.utils.checkpoint as cp
 from mmcv.cnn import build_conv_layer, build_norm_layer
+from mmengine.model import BaseModule
 
-from ..builder import BACKBONES
+from mmpose.registry import MODELS
 from .resnet import Bottleneck as _Bottleneck
 from .resnet import ResLayer, ResNetV1d
 
@@ -34,7 +35,7 @@ class RSoftmax(nn.Module):
         return x
 
 
-class SplitAttentionConv2d(nn.Module):
+class SplitAttentionConv2d(BaseModule):
     """Split-Attention Conv2d.
 
     Args:
@@ -51,6 +52,8 @@ class SplitAttentionConv2d(nn.Module):
         conv_cfg (dict): Config dict for convolution layer. Default: None,
             which means using conv2d.
         norm_cfg (dict): Config dict for normalization layer. Default: None.
+        init_cfg (dict or list[dict], optional): Initialization config dict.
+            Default: None
     """
 
     def __init__(self,
@@ -64,8 +67,9 @@ class SplitAttentionConv2d(nn.Module):
                  radix=2,
                  reduction_factor=4,
                  conv_cfg=None,
-                 norm_cfg=dict(type='BN')):
-        super().__init__()
+                 norm_cfg=dict(type='BN'),
+                 init_cfg=None):
+        super().__init__(init_cfg=init_cfg)
         inter_channels = max(in_channels * radix // reduction_factor, 32)
         self.radix = radix
         self.groups = groups
@@ -157,6 +161,8 @@ class Bottleneck(_Bottleneck):
             Default: dict(type='BN')
         with_cp (bool): Use checkpoint or not. Using checkpoint will save some
             memory while slowing down the training speed.
+        init_cfg (dict or list[dict], optional): Initialization config dict.
+            Default: None
     """
 
     def __init__(self,
@@ -256,12 +262,12 @@ class Bottleneck(_Bottleneck):
         return out
 
 
-@BACKBONES.register_module()
+@MODELS.register_module()
 class ResNeSt(ResNetV1d):
     """ResNeSt backbone.
 
-    Please refer to the `paper <https://arxiv.org/pdf/2004.08955.pdf>`_ for
-    details.
+    Please refer to the `paper <https://arxiv.org/pdf/2004.08955.pdf>`__
+    for details.
 
     Args:
         depth (int): Network depth, from {50, 101, 152, 200}.
@@ -302,6 +308,15 @@ class ResNeSt(ResNetV1d):
             memory while slowing down the training speed. Default: False.
         zero_init_residual (bool): Whether to use zero init for last norm layer
             in resblocks to let them behave as identity. Default: True.
+        init_cfg (dict or list[dict], optional): Initialization config dict.
+            Default:
+            ``[
+                dict(type='Kaiming', layer=['Conv2d']),
+                dict(
+                    type='Constant',
+                    val=1,
+                    layer=['_BatchNorm', 'GroupNorm'])
+            ]``
     """
 
     arch_settings = {
