@@ -1,14 +1,96 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 import math
+from functools import partial
 
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
 
-from ..builder import LOSSES
+from mmpose.registry import MODELS
+from ..utils.realnvp import RealNVP
 
 
-@LOSSES.register_module()
+@MODELS.register_module()
+class RLELoss(nn.Module):
+    """RLE Loss.
+
+    `Human Pose Regression With Residual Log-Likelihood Estimation
+    arXiv: <https://arxiv.org/abs/2107.11291>`_.
+
+    Code is modified from `the official implementation
+    <https://github.com/Jeff-sjtu/res-loglikelihood-regression>`_.
+
+    Args:
+        use_target_weight (bool): Option to use weighted loss.
+            Different joint types may have different target weights.
+        size_average (bool): Option to average the loss by the batch_size.
+        residual (bool): Option to add L1 loss and let the flow
+            learn the residual error distribution.
+        q_dis (string): Option for the identity Q(error) distribution,
+            Options: "laplace" or "gaussian"
+    """
+
+    def __init__(self,
+                 use_target_weight=False,
+                 size_average=True,
+                 residual=True,
+                 q_distribution='laplace'):
+        super(RLELoss, self).__init__()
+        self.size_average = size_average
+        self.use_target_weight = use_target_weight
+        self.residual = residual
+        self.q_distribution = q_distribution
+
+        self.flow_model = RealNVP()
+
+    def forward(self, pred, sigma, target, target_weight=None):
+        """Forward function.
+
+        Note:
+            - batch_size: N
+            - num_keypoints: K
+            - dimension of keypoints: D (D=2 or D=3)
+
+        Args:
+            pred (Tensor[N, K, D]): Output regression.
+            sigma (Tensor[N, K, D]): Output sigma.
+            target (Tensor[N, K, D]): Target regression.
+            target_weight (Tensor[N, K, D]):
+                Weights across different joint types.
+        """
+        sigma = sigma.sigmoid()
+
+        error = (pred - target) / (sigma + 1e-9)
+        # (B, K, 2)
+        log_phi = self.flow_model.log_prob(error.reshape(-1, 2))
+        log_phi = log_phi.reshape(target.shape[0], target.shape[1], 1)
+        log_sigma = torch.log(sigma).reshape(target.shape[0], target.shape[1],
+                                             2)
+        nf_loss = log_sigma - log_phi
+
+        if self.residual:
+            assert self.q_distribution in ['laplace', 'gaussian']
+            if self.q_distribution == 'laplace':
+                loss_q = torch.log(sigma * 2) + torch.abs(error)
+            else:
+                loss_q = torch.log(
+                    sigma * math.sqrt(2 * math.pi)) + 0.5 * error**2
+
+            loss = nf_loss + loss_q
+        else:
+            loss = nf_loss
+
+        if self.use_target_weight:
+            assert target_weight is not None
+            loss *= target_weight
+
+        if self.size_average:
+            loss /= len(loss)
+
+        return loss.sum()
+
+
+@MODELS.register_module()
 class SmoothL1Loss(nn.Module):
     """SmoothL1Loss loss.
 
@@ -38,8 +120,14 @@ class SmoothL1Loss(nn.Module):
             target_weight (torch.Tensor[N, K, D]):
                 Weights across different joint types.
         """
+
         if self.use_target_weight:
             assert target_weight is not None
+            assert output.ndim >= target_weight.ndim
+
+            for i in range(output.ndim - target_weight.ndim):
+                target_weight = target_weight.unsqueeze(-1)
+
             loss = self.criterion(output * target_weight,
                                   target * target_weight)
         else:
@@ -48,7 +136,88 @@ class SmoothL1Loss(nn.Module):
         return loss * self.loss_weight
 
 
-@LOSSES.register_module()
+@MODELS.register_module()
+class SoftWeightSmoothL1Loss(nn.Module):
+    """Smooth L1 loss with soft weight for regression.
+
+    Args:
+        use_target_weight (bool): Option to use weighted MSE loss.
+            Different joint types may have different target weights.
+        supervise_empty (bool): Whether to supervise the output with zero
+            weight.
+        beta (float):  Specifies the threshold at which to change between
+            L1 and L2 loss.
+        loss_weight (float): Weight of the loss. Default: 1.0.
+    """
+
+    def __init__(self,
+                 use_target_weight=False,
+                 supervise_empty=True,
+                 beta=1.0,
+                 loss_weight=1.):
+        super().__init__()
+
+        reduction = 'none' if use_target_weight else 'mean'
+        self.criterion = partial(
+            self.smooth_l1_loss, reduction=reduction, beta=beta)
+
+        self.supervise_empty = supervise_empty
+        self.use_target_weight = use_target_weight
+        self.loss_weight = loss_weight
+
+    @staticmethod
+    def smooth_l1_loss(input, target, reduction='none', beta=1.0):
+        """Re-implement torch.nn.functional.smooth_l1_loss with beta to support
+        pytorch <= 1.6."""
+        delta = input - target
+        mask = delta.abs() < beta
+        delta[mask] = (delta[mask]).pow(2) / (2 * beta)
+        delta[~mask] = delta[~mask].abs() - beta / 2
+
+        if reduction == 'mean':
+            return delta.mean()
+        elif reduction == 'sum':
+            return delta.sum()
+        elif reduction == 'none':
+            return delta
+        else:
+            raise ValueError(f'reduction must be \'mean\', \'sum\' or '
+                             f'\'none\', but got \'{reduction}\'')
+
+    def forward(self, output, target, target_weight=None):
+        """Forward function.
+
+        Note:
+            - batch_size: N
+            - num_keypoints: K
+            - dimension of keypoints: D (D=2 or D=3)
+
+        Args:
+            output (torch.Tensor[N, K, D]): Output regression.
+            target (torch.Tensor[N, K, D]): Target regression.
+            target_weight (torch.Tensor[N, K, D]):
+                Weights across different joint types.
+        """
+        if self.use_target_weight:
+            assert target_weight is not None
+            assert output.ndim >= target_weight.ndim
+
+            for i in range(output.ndim - target_weight.ndim):
+                target_weight = target_weight.unsqueeze(-1)
+
+            loss = self.criterion(output, target) * target_weight
+            if self.supervise_empty:
+                loss = loss.mean()
+            else:
+                num_elements = torch.nonzero(target_weight > 0).size()[0]
+                loss = loss.sum() / max(num_elements, 1.0)
+        else:
+            loss = self.criterion(output, target)
+
+        return loss * self.loss_weight
+
+
+@MODELS.register_module()
 class WingLoss(nn.Module):
     """Wing Loss. paper ref: 'Wing Loss for Robust Facial Landmark Localisation
     with Convolutional Neural Networks' Feng et al. CVPR'2018.
@@ -118,7 +287,7 @@ class WingLoss(nn.Module):
         return loss * self.loss_weight
 
 
-@LOSSES.register_module()
+@MODELS.register_module()
 class SoftWingLoss(nn.Module):
     """Soft Wing Loss 'Structure-Coherent Deep Feature Learning for Robust Face
     Alignment' Lin et al. TIP'2021.
@@ -196,7 +365,7 @@ class SoftWingLoss(nn.Module):
         return loss * self.loss_weight
 
 
-@LOSSES.register_module()
+@MODELS.register_module()
 class MPJPELoss(nn.Module):
     """MPJPE (Mean Per Joint Position Error) loss.
 
@@ -236,7 +405,7 @@ class MPJPELoss(nn.Module):
         return loss * self.loss_weight
 
 
-@LOSSES.register_module()
+@MODELS.register_module()
 class L1Loss(nn.Module):
     """L1Loss loss ."""
 
@@ -269,7 +438,7 @@ class L1Loss(nn.Module):
         return loss * self.loss_weight
 
 
-@LOSSES.register_module()
+@MODELS.register_module()
 class MSELoss(nn.Module):
     """MSE loss for coordinate regression."""
 
@@ -292,6 +461,7 @@ class MSELoss(nn.Module):
             target_weight (torch.Tensor[N, K, 2]):
                 Weights across different joint types.
         """
+
         if self.use_target_weight:
             assert target_weight is not None
             loss = self.criterion(output * target_weight,
@@ -302,7 +472,7 @@ class MSELoss(nn.Module):
         return loss * self.loss_weight
 
 
-@LOSSES.register_module()
+@MODELS.register_module()
 class BoneLoss(nn.Module):
     """Bone length loss.
 
@@ -356,7 +526,7 @@ class BoneLoss(nn.Module):
         return loss * self.loss_weight
 
 
-@LOSSES.register_module()
+@MODELS.register_module()
 class SemiSupervisionLoss(nn.Module):
     """Semi-supervision loss for unlabeled data. It is composed of projection
     loss and bone loss.
