@@ -1,6 +1,9 @@
 # Copyright (c) OpenMMLab. All rights reserved.
+from .fmap_proc_neck import FeatureMapProcessor
 from .fpn import FPN
 from .gap_neck import GlobalAveragePooling
 from .posewarper_neck import PoseWarperNeck
 
-__all__ = ['GlobalAveragePooling', 'PoseWarperNeck', 'FPN']
+__all__ = [
+    'GlobalAveragePooling', 'PoseWarperNeck', 'FPN', 'FeatureMapProcessor'
+]
